@@ -73,7 +73,7 @@ class BaseTemps():
         return copy.deepcopy(self)
 
     def __str__(self):
-        return str([self.Nmin, self.Nmax, self. NTa, self.sysam])
+        return str([self.Nmin, self.Nmax, self. NTa, self.Nsysam])
 
     def __eq__(self, other):
         return self.Nmin == other.Nmin and self.Nmax == other.Nmax and  self.NTa == other.NTa and  self.Nsysam == other.Nsysam 
