@@ -191,7 +191,7 @@ class SignalGBF(SignalComplet):
     def __init__(self, type_signal = "cosinus", F=1, Vpp= 1, offset = 0, tr=0., phi = 0., alpha = 0.5, liste_tmin_tmax = cst.liste_tmin_tmax, Te = cst.Te, nom = ""):
         if type_signal not in liste_types_signaux_gbf:
             print("Ce type de signaux n'existe pas")
-            exit()
+            sys.exit()
         if type_signal == "cosinus":
             SignalSinus.__init__(self, F, Vpp, offset, phi, tr, liste_tmin_tmax, Te, nom)
         elif type_signal == "carre":
