@@ -20,11 +20,11 @@ import base.utiles_base as utb
 class Sysam1Base():
     def __init__(self, liste_signaux = None):
         self.sysam = pycan.Sysam("SP5")
-        if len(liste_signaux) > 0:
+        if isinstance(liste_signaux, list) and len(liste_signaux)> 0:
             self.liste_signaux = liste_signaux
         else:
             print("Pas de signaux")
-            exit()
+            sys.exit()
         utb.print_liste(self.liste_signaux)
 
         self.liste_entrees_simples = utb.lister_test(self.liste_signaux, 
@@ -83,6 +83,8 @@ class Sysam1Base():
 
 if __name__ == "__main__":
 
+    sysam = Sysam1Base()
+    
     liste_tmin_tmax = [0, 2e-3]
     Te = 1e-4
 
