@@ -28,7 +28,7 @@ class Sysam3Test(Sysam2Mode):
             self.test_signaux = True
         else:
             self.test_signaux = False
-            exit()
+            sys.exit()
 
 
     ##################################################################################################################
